@@ -1,7 +1,12 @@
-from asyncio import Future, Lock, Task, create_task, gather, wait, wait_for
+from asyncio import Future, Lock, Task, gather, wait, wait_for
+
+try:
+    from asyncio import create_task
+except ImportError:
+    from asyncio import ensure_future as create_task
 
 __all__ = ("ServiceMixin",)
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 version = tuple(map(int, __version__.split(".")))
 
 
